@@ -417,11 +417,11 @@ void scen_create_pg_weather( FILE *dest_file, int scen_id, FILE *scen_file, int
         "ffffffffffsooofffffoosos",
         "ffffffroforofff"
     };
-    int i;
+    int i, wlen = strlen(weathers[scen_id]);
     char w[32];
     if (strlen(weathers[scen_id])>0&&strlen(weathers[scen_id])!=turns)
         fprintf(stderr,"ERROR: scen %d: mismatch in length of weather (%d) and turn number (%d)\n",
-                scen_id,strlen(weathers[scen_id]),turns);
+                scen_id,wlen,turns);
     /* write weather */
     fprintf( dest_file, "weather=" );
     i = 0;
