@@ -233,8 +233,9 @@ static int get_nation_from_unit_name( const char *uname )
 	int i = 0;
 	
     /* only guess for PG unit database */
-    if ( !apply_unit_mods )
+    if ( !apply_unit_mods ) {
         return -1;
+    }
     
 	while (id_map[i].id[0] != 'x') {
 		if (strncmp(id_map[i].id, uname, strlen(id_map[i].id)) == 0) {
