@@ -61,8 +61,8 @@ void reset_config()
     config.tran = 1;
     config.grid = 0;
     config.show_bar = 1;
-    config.width = 640;
-    config.height = 480;
+    config.width = 800;
+    config.height = 600;
     config.fullscreen = 0;
     config.anim_speed = 1;
     /* game options */
@@ -83,13 +83,13 @@ void reset_config()
 /* load config */
 void load_config( )
 {
-    char file_name[512];
+    char file_name[1024];
     PData *pd; 
     /* set to defaults */
     check_config_dir_name();
     reset_config();
     /* load config */
-    sprintf( file_name, "%s/%s", config.dir_name, "lgeneral.conf" );
+    snprintf( file_name, 1024, "%s/%s", config.dir_name, "lgeneral.conf" );
     if ( ( pd = parser_read_file( "config", file_name ) ) == 0 ) {
         fprintf( stderr, "%s\n", parser_get_error() );
         return;
@@ -120,9 +120,9 @@ void load_config( )
 void save_config( )
 {
     FILE *file = 0;
-    char file_name[512];
+    char file_name[1024];
 
-    sprintf( file_name, "%s/%s", config.dir_name, "lgeneral.conf" );
+    snprintf( file_name, 1024, "%s/%s", config.dir_name, "lgeneral.conf" );
     if ( ( file = fopen( file_name, "wb" ) ) == 0 )
         fprintf( stderr, tr("Cannot access config file '%s' to save settings\n"), file_name );
     else {
