@@ -109,13 +109,19 @@ int deploy_show_count = 7; /* number of displayed units in list */
 int unit_list_offset = 0; /* offset in unit_list */
 int unit_list_max_offset = 0;
 int unit_list_graphical_offset=150; /* y-offset for rendering in dialog */ 
-int gui_panel_w = 220;	/* size of fixed GUI panel */;
+int gui_panel_w = 44;	/* size of fixed GUI panel */;
 
 /*
 ====================================================================
 Create a frame surface
 ====================================================================
 */
+SDL_Surface *gui_create_empty_frame( int w, int h )
+{
+	SDL_Surface *surf = create_surf( w, h, SDL_SWSURFACE );
+	SDL_FillRect( surf, 0, 0x0 );
+	    return surf;
+}
 SDL_Surface *gui_create_frame( int w, int h )
 {
     int i;
@@ -272,8 +278,9 @@ int gui_load( const char *dir )
         goto failure;
     frame_hide( gui->qinfo2, 1 );
     /* minimap */
-    if ( ( gui->minimap = mmview_create( 210, 210 )) == 0 )
+    if ( ( gui->minimap = mmview_create( 132, 132 )) == 0 )
         goto failure;
+    mmview_hide(gui->minimap,1);
     /* full unit info */
     if ( ( gui->finfo = frame_create( gui_create_frame( 460, 280 ), 200, sdl.screen, 0, 0 ) ) == 0 )
         goto failure;
@@ -296,29 +303,30 @@ int gui_load( const char *dir )
     group_add_button( gui->confirm, ID_CANCEL, sx, sy, 0, tr("Cancel") );
     group_hide( gui->confirm, 1 );
     /* unit buttons */
-    sx = 6; sy = 6;
-    dx = dy = 51;
+    sx = sy = 4;
+    dx = dy = 38;
     sprintf( path2, "../themes/%s/unit_buttons.bmp", dir );
-    if ( ( gui->unit_buttons = group_create( gui_create_frame( 2*sx+4*dx-3, 2*sy+2*dy-3 ), 160, load_surf( path2, SDL_SWSURFACE ),
-                                             48, 48, 7, ID_SUPPLY, gui->label, sdl.screen, 0, 0 ) ) == 0 )
+    if ( ( gui->unit_buttons = group_create( gui_create_frame( 2*sx+4*dx, 2*sy+2*dy ), 160, load_surf( path2, SDL_SWSURFACE ),
+                                             36, 36, 7, ID_SUPPLY, gui->label, sdl.screen, 0, 0 ) ) == 0 )
         goto failure;
     group_add_button( gui->unit_buttons, ID_UNDO, sx, sy, 0, tr("Undo Turn [u]") ); sx += dx;
     group_add_button( gui->unit_buttons, ID_SUPPLY, sx, sy, 0, tr("Supply Unit [s]") ); sx += dx;
     group_add_button( gui->unit_buttons, ID_EMBARK_AIR, sx, sy, 0, tr("Air Embark") ); sx += dx;
-    group_add_button( gui->unit_buttons, ID_RENAME, sx, sy, 0, tr("Rename Unit") ); sx = 6; sy += dy;
+    group_add_button( gui->unit_buttons, ID_RENAME, sx, sy, 0, tr("Rename Unit") ); sx = 3; sy += dy;
     group_add_button( gui->unit_buttons, ID_MERGE, sx, sy, 0, tr("Merge Unit [j]") ); sx += dx;
     group_add_button( gui->unit_buttons, ID_SPLIT, sx, sy, 0, tr("Split Unit [x+1..9]") ); sx += 2*dx;
-    group_add_button( gui->unit_buttons, ID_DISBAND, sx, sy, 0, tr("Disband Unit") ); 
+    group_add_button( gui->unit_buttons, ID_DISBAND, sx, sy, 0, tr("Disband Unit") );
+    group_hide( gui->unit_buttons, 1 );
     /* split menu */
     sprintf( path2, "../themes/%s/strength_buttons.bmp", dir );
-    if ( ( gui->split_menu = group_create( gui_create_frame( 40, 296 ), 200, load_surf( path2, SDL_SWSURFACE ),
+    if ( ( gui->split_menu = group_create( gui_create_frame( 296, 40 ), 200, load_surf( path2, SDL_SWSURFACE ),
                                           32, 32, 10, ID_SPLIT_1, gui->label, sdl.screen, 0, 0 ) ) == 0 )
         goto failure;
     sx = 4; sy = 4;
     for ( i = 0; i < 9; i++ ) {
         sprintf( str, tr("Split Up %d Strength"), i+1 );
         group_add_button( gui->split_menu, ID_SPLIT_1 + i, sx, sy, 0, str );
-        sy += 32;
+        sx += 32;
     }
     group_hide( gui->split_menu, 1 );
     /* deploy window */
@@ -338,33 +346,35 @@ int gui_load( const char *dir )
         goto failure;
     edit_hide( gui->edit, 1 );
     /* base menu */
-    sx = 6; sy = 6;
-    dx = dy = 51;
+    sx = 0; sy = 0;
+    dx = 36;
+    dy = 36;
     sprintf( path2, "../themes/%s/menu0_buttons.bmp", dir );
-    if ( ( gui->base_menu = group_create( gui_create_frame( 2*sx+4*dx-3, 2*sy+2*dy-3 ), 160, load_surf( path2, SDL_SWSURFACE ),
-                                          48, 48, 9, ID_MENU, gui->label, sdl.screen, 0, 0 ) ) == 0 )
+    if ( ( gui->base_menu = group_create( gui_create_empty_frame( 2*sx+dx, 2*sy+8*dy ), 160, load_surf( path2, SDL_SWSURFACE ),
+                                          36, 36, 8, ID_MENU, gui->label, sdl.screen, 0, 0 ) ) == 0 )
         goto failure;
-    group_add_button( gui->base_menu, ID_AIR_MODE, sx, sy, 0, tr("Switch Air/Ground [t]") ); sx += dx;
-    group_add_button( gui->base_menu, ID_STRAT_MAP, sx, sy, 0, tr("Strategic Map [o]") ); sx += dx;
-    group_add_button( gui->base_menu, ID_PURCHASE, sx, sy, 0, tr("Request Reinforcements") ); sx += dx;
-    group_add_button( gui->base_menu, ID_DEPLOY, sx, sy, 0, tr("Deploy Reinforcements [d]") ); sx = 6; sy += dy;
-    group_add_button( gui->base_menu, ID_UNIT_LIST, sx, sy, 0, tr("Unit List") ); sx += dx;
-    group_add_button( gui->base_menu, ID_SCEN_INFO, sx, sy, 0, tr("Scenario Info [i]") ); sx += dx;
-    group_add_button( gui->base_menu, ID_CONDITIONS, sx, sy, 0, tr("Victory Conditions") ); sx += dx;
+    group_add_button( gui->base_menu, ID_AIR_MODE, sx, sy, 0, tr("Switch Air/Ground [t]") ); sy += dy;
+    group_add_button( gui->base_menu, ID_STRAT_MAP, sx, sy, 0, tr("Minimap [o]") ); sy += dy;
+    group_add_button( gui->base_menu, ID_PURCHASE, sx, sy, 0, tr("Request Reinforcements") ); sy += dy;
+    group_add_button( gui->base_menu, ID_DEPLOY, sx, sy, 0, tr("Deploy Reinforcements [d]") ); sy += dy;
+    group_add_button( gui->base_menu, ID_UNIT_LIST, sx, sy, 0, tr("Unit List") ); sy += dy;
+    group_add_button( gui->base_menu, ID_SCEN_INFO, sx, sy, 0, tr("Scenario Info [i]") ); sy += dy;
+    group_add_button( gui->base_menu, ID_CONDITIONS, sx, sy, 0, tr("Victory Conditions") ); sy += dy;
     group_add_button( gui->base_menu, ID_END_TURN, sx, sy, 0, tr("End Turn [e]") );
     /* main_menu */
-    sx = 6; sy = 6;
-    dx = dy = 51;
+    sx = 0; sy = 0;
+    dx = 36;
+    dy = 36;
     sprintf( path2, "../themes/%s/menu1_buttons.bmp", dir );
-    if ( ( gui->main_menu = group_create( gui_create_frame( 2*sx+4*dx-3, 2*sy+2*dy-3 ), 160, load_surf( path2, SDL_SWSURFACE ),
-                                          48, 48, 7, ID_SAVE, gui->label, sdl.screen, 0, 0 ) ) == 0 )
+    if ( ( gui->main_menu = group_create( gui_create_empty_frame( 2*sx+dx, 2*sy+7*dy ), 160, load_surf( path2, SDL_SWSURFACE ),
+                                          36, 36, 7, ID_SAVE, gui->label, sdl.screen, 0, 0 ) ) == 0 )
         goto failure;
-    group_add_button( gui->main_menu, ID_SAVE, sx, sy, 0, tr("Save Game") ); sx += dx;
-    group_add_button( gui->main_menu, ID_LOAD, sx, sy, 0, tr("Load Game") ); sx += dx;
-    group_add_button( gui->main_menu, ID_SCEN, sx, sy, 0, tr("Load Scenario") ); sx += dx;
-    group_add_button( gui->main_menu, ID_CAMP, sx, sy, 0, tr("Load Campaign") ); sx = 6; sy += dy;
-    group_add_button( gui->main_menu, ID_OPTIONS, sx, sy, 0, tr("Options") ); sx += dx;
-    group_add_button( gui->main_menu, ID_RESTART, sx, sy, 0, tr("Restart Scenario") ); sx += 2*dx;
+    group_add_button( gui->main_menu, ID_SAVE, sx, sy, 0, tr("Save Game") ); sy += dy;
+    group_add_button( gui->main_menu, ID_LOAD, sx, sy, 0, tr("Load Game") ); sy += dy;
+    group_add_button( gui->main_menu, ID_SCEN, sx, sy, 0, tr("Load Scenario") ); sy += dy;
+    group_add_button( gui->main_menu, ID_CAMP, sx, sy, 0, tr("Load Campaign") ); sy += dy;
+    group_add_button( gui->main_menu, ID_OPTIONS, sx, sy, 0, tr("Options") ); sy += dy;
+    group_add_button( gui->main_menu, ID_RESTART, sx, sy, 0, tr("Restart Scenario") ); sy += dy;
     group_add_button( gui->main_menu, ID_QUIT, sx, sy, 0, tr("Quit Game") );
     /* load menu */
     sprintf( path2, "../themes/%s/menu2_buttons.bmp", dir );
@@ -392,12 +402,12 @@ int gui_load( const char *dir )
     }
     group_hide( gui->save_menu, 1 );
     /* options */
-    sprintf( path2, "../themes/%s/menu3_buttons.bmp", dir );
-    if ( ( gui->opt_menu = group_create( gui_create_frame( 54, 6+7*54 ), 200, load_surf( path2, SDL_SWSURFACE ),
-                                          48, 48, 10, ID_C_SUPPLY, gui->label, sdl.screen, 0, 0 ) ) == 0 )
-        goto failure;
     sx = 3; sy = 3;
-    dy = 54;
+    dx = dy = 36;
+    sprintf( path2, "../themes/%s/menu3_buttons.bmp", dir );
+    if ( ( gui->opt_menu = group_create( gui_create_frame( sx*2+dx, 2*sy+7*dy ), 200, load_surf( path2, SDL_SWSURFACE ),
+                                          36, 36, 10, ID_C_SUPPLY, gui->label, sdl.screen, 0, 0 ) ) == 0 )
+        goto failure;
     //group_add_button( gui->opt_menu, ID_C_SUPPLY, sx, sy, 1, "Unit Supply" ); sy += 30;
     //group_add_button( gui->opt_menu, ID_C_WEATHER, sx, sy, 1, "Weather Influence" ); sy += 30;
     group_add_button( gui->opt_menu, ID_C_GRID, sx, sy, 1, tr("Hex Grid [g]") ); sy += dy;
@@ -539,55 +549,33 @@ measurements.
 void gui_adjust()
 {
 	int sw = sdl.screen->w, sh = sdl.screen->h;
-	int cx, cy = 10;
+	int cx;
 	int panel_x = sdl.screen->w - gui_panel_w;
 
 	/* panel */
 	frame_move(gui->panel, sw - gui_panel_w, 0);
 	/* info labels + edit */
-	if (sh <= 600) {
-		int label_top = 10;
-		cx = (sw - gui_panel_w - gui->label->frame->img->img->w) / 2;
-		label_move( gui->label, cx, label_top );
-		label_top += gui->label->frame->img->img->h;
-		label_move( gui->label2, cx, label_top );
-		cx = ( sw - gui_panel_w - gui->edit->label->frame->img->img->w)/2;
-		edit_move( gui->edit, cx, label_top );
-	} else {
-		cx = panel_x + (gui_panel_w - gui->label->frame->img->img->w)/2;
-		label_move( gui->label, cx, cy );
-		cy += gui->label->frame->img->img->h;
-		label_move( gui->label2, cx, cy );
-		cx = panel_x + (gui_panel_w - gui->edit->label->frame->img->img->w)/2;
-		edit_move( gui->edit, cx, cy );
-		cy += gui->label->frame->img->img->h + 5;
-	}
-	/* unit menu */
-	cx = panel_x + (gui_panel_w - gui->unit_buttons->frame->img->img->w)/2;
-	group_move(gui->unit_buttons, cx, cy);
-	cy += gui->unit_buttons->frame->img->img->h;
+	int label_top = 10;
+	cx = (sw - gui_panel_w - gui->label->frame->img->img->w) / 2;
+	label_move( gui->label, cx, label_top );
+	label_top += gui->label->frame->img->img->h;
+	label_move( gui->label2, cx, label_top );
+	cx = ( sw - gui_panel_w - gui->edit->label->frame->img->img->w)/2;
+	edit_move( gui->edit, cx, label_top );
 	/* basic menu */
 	cx = panel_x + (gui_panel_w - gui->base_menu->frame->img->img->w)/2;
-	group_move(gui->base_menu, cx, cy );
-	cy += gui->base_menu->frame->img->img->h + 10;
+	group_move(gui->base_menu, cx, 6 );
 	/* unit infos */
-	if (sh <= 600) {
-		int dist = 10;
-		frame_move( gui->qinfo1, dist, sh - dist - gui->qinfo1->img->img->h );
-		frame_move( gui->qinfo2, dist, sh - dist - 2*gui->qinfo1->img->img->h );
-	} else {
-		cx = panel_x + (gui_panel_w - gui->qinfo1->img->img->w)/2;
-		frame_move( gui->qinfo1, cx, cy );
-		cy += gui->qinfo1->img->img->h;
-		frame_move( gui->qinfo2, cx, cy );
-		cy += gui->qinfo2->img->img->h + 5;
-	}
+	int dist = 10;
+	frame_move( gui->qinfo1, dist, sh - dist - gui->qinfo1->img->img->h );
+	frame_move( gui->qinfo2, dist, sh - dist - 2*gui->qinfo1->img->img->h );
 	/* minimap */
-	cx = panel_x + (gui_panel_w - gui->minimap->w)/2;
-	mmview_move( gui->minimap, cx, cy);
+	mmview_move( gui->minimap,
+				panel_x - gui->minimap->w - 10,
+				sh - gui->minimap->h - 10);
 	/* main menu */
 	cx = panel_x + (gui_panel_w - gui->main_menu->frame->img->img->w)/2;
-	group_move(gui->main_menu, cx, sdl.screen->h - gui->main_menu->frame->img->img->h - 10 );
+	group_move(gui->main_menu, cx, sdl.screen->h - gui->main_menu->frame->img->img->h -6 );
 	/* full info */
 	frame_move( gui->finfo, ( sdl.screen->w - gui_panel_w - gui->finfo->img->img->w ) >> 1, ( sdl.screen->h - gui->finfo->img->img->h ) >> 1 );
 	frame_move( gui->unit_list, ( sdl.screen->w - gui_panel_w - gui->unit_list->img->img->w ) >> 1, ( sdl.screen->h - gui->unit_list->img->img->h ) >> 1 );
@@ -632,7 +620,7 @@ Hide/draw from/to screen
 */
 void gui_get_bkgnds()
 {
-	frame_get_bkgnd( gui->panel );
+    frame_get_bkgnd( gui->panel );
     label_get_bkgnd( gui->label );
     label_get_bkgnd( gui->label2 );
     frame_get_bkgnd( gui->qinfo1 );
@@ -659,23 +647,22 @@ void gui_get_bkgnds()
 }
 void gui_draw_bkgnds()
 {
-	frame_draw_bkgnd( gui->panel ); // includes some windows
-	if (sdl.screen->h <= 600) {
-		label_draw_bkgnd( gui->label );
-		label_draw_bkgnd( gui->label2 );
-		frame_draw_bkgnd( gui->qinfo1 );
-		frame_draw_bkgnd( gui->qinfo2 );
-		edit_draw_bkgnd( gui->edit );
-	}
+    frame_draw_bkgnd( gui->panel ); // includes some windows
+    label_draw_bkgnd( gui->label );
+    label_draw_bkgnd( gui->label2 );
+    frame_draw_bkgnd( gui->qinfo1 );
+    frame_draw_bkgnd( gui->qinfo2 );
+    edit_draw_bkgnd( gui->edit );
     frame_draw_bkgnd( gui->finfo ); 
     frame_draw_bkgnd( gui->unit_list ); 
     frame_draw_bkgnd( gui->sinfo );
+    mmview_draw_bkgnd(gui->minimap);
     //group_draw_bkgnd( gui->base_menu );
     //group_draw_bkgnd( gui->main_menu );
     group_draw_bkgnd( gui->load_menu );
     group_draw_bkgnd( gui->save_menu );
     group_draw_bkgnd( gui->opt_menu );
-    //group_draw_bkgnd( gui->unit_buttons);
+    group_draw_bkgnd( gui->unit_buttons);
     group_draw_bkgnd( gui->split_menu );
     group_draw_bkgnd( gui->confirm );
     group_draw_bkgnd( gui->deploy_window );
@@ -687,7 +674,7 @@ void gui_draw_bkgnds()
 }
 void gui_draw()
 {
-	frame_draw(gui->panel);
+    frame_draw(gui->panel);
     label_draw( gui->label ); 
     label_draw( gui->label2 ); 
     frame_draw( gui->qinfo1 ); 
@@ -838,17 +825,17 @@ void gui_show_quick_info( Frame *qinfo, Unit *unit )
 	}
     /* name - clip to 16 chars */
     gui->font_std->align = ALIGN_X_LEFT | ALIGN_Y_TOP;
+    snprintf(str,64,"%s",unit->name);
     if (strlen(unit->name) > 16) {
-	    snprintf(str,17,"%s",unit->name);
 	    str[15] = str[14] = str[13] = '.';
-    } else
-	    sprintf(str,"%s",unit->name);
+	    str[16] = 0;
+    }
     write_text( gui->font_std, qinfo->contents, 12 + hex_w, 10, str, 255 );
+    snprintf(str,64,"%s",unit->prop.name);
     if (strlen(unit->prop.name) > 16) {
-	    snprintf(str,17,"%s",unit->prop.name);
 	    str[15] = str[14] = str[13] = '.';
-    } else
-	    sprintf(str,"%s",unit->prop.name);
+	    str[16] = 0;
+    }
     write_text( gui->font_std, qinfo->contents, 12 + hex_w, 22, str, 255 );
     /* status */
     gui->font_status->align = ALIGN_X_LEFT | ALIGN_Y_TOP;
@@ -975,7 +962,7 @@ void gui_show_full_info( Unit *unit )
     /* tag (if any) */
     if (unit->tag[0] != 0) {
 		x = border; y = border + hex_h - gui->font_std->height;
-		snprintf(str,8,"[%s]",unit->tag);
+		snprintf(str,128,"[%s]",unit->tag);
 		write_line( contents, gui->font_std, str, x, &y );
 	}
     /* name and type */
@@ -992,9 +979,9 @@ void gui_show_full_info( Unit *unit )
 		y += 10;
     write_line( contents, gui->font_std, unit_classes[unit->prop.class].name, x, &y );
     //y += 10;
-    sprintf( str, tr("%s Movement"), mov_types[unit->prop.mov_type].name );
+    snprintf( str, 128, tr("%s Movement"), mov_types[unit->prop.mov_type].name );
     write_line( contents, gui->font_std, str, x, &y );
-    sprintf( str, tr("%s Target"), trgt_types[unit->prop.trgt_type].name );
+    snprintf( str, 128, tr("%s Target"), trgt_types[unit->prop.trgt_type].name );
     write_line( contents, gui->font_std, str, x, &y );
     /* ammo, fuel, spot, mov, ini, range */
     x = border + hex_w + 90; y = border;
@@ -1192,7 +1179,7 @@ void gui_render_subcond( VSubCond *cond, char *str )
 }
 void gui_show_conds()
 {
-    char str[128];
+    char str[256];
     int border = 10, i, j;
     int x = border, y = border;
     SDL_Surface *contents = gui->sinfo->contents;
@@ -1203,21 +1190,21 @@ void gui_show_conds()
              (vcond_check_type==VCOND_CHECK_EVERY_TURN)?tr("every turn"):tr("last turn") ); 
     write_line( contents, gui->font_std, str, x, &y ); y += 10;
     for ( i = 1; i < vcond_count; i++ ) {
-        sprintf( str, "'%s':", vconds[i].message );
+        snprintf( str, 256, "'%s':", vconds[i].message );
         write_line( contents, gui->font_std, str, x, &y );
         for ( j = 0; j < vconds[i].sub_and_count; j++ ) {
             if ( vconds[i].subconds_and[j].player )
-                sprintf( str, tr("AND %.2s "), vconds[i].subconds_and[j].player->name );
+                snprintf( str, 256, tr("AND %.2s "), vconds[i].subconds_and[j].player->name );
             else
-                sprintf( str, tr("AND -- ") );
+                snprintf( str, 256, tr("AND -- ") );
             gui_render_subcond( &vconds[i].subconds_and[j], str + 7 );
             write_line( contents, gui->font_std, str, x, &y );
         }
         for ( j = 0; j < vconds[i].sub_or_count; j++ ) {
             if ( vconds[i].subconds_or[j].player )
-                sprintf( str, tr("OR %.2s "), vconds[i].subconds_or[j].player->name );
+                snprintf( str, 256, tr("OR %.2s "), vconds[i].subconds_or[j].player->name );
             else
-                sprintf( str, tr("OR -- ") );
+                snprintf( str, 256, tr("OR -- ") );
             gui_render_subcond( &vconds[i].subconds_or[j], str + 6 );
             write_line( contents, gui->font_std, str, x, &y );
         }
@@ -2094,26 +2081,25 @@ Unit *gui_unit_list_unit_clicked( List * units ,int cx,int cy)
 void gui_panel_hide()
 {
 	frame_hide(gui->panel,1);
-	group_hide(gui->unit_buttons,1);
-	group_hide(gui->split_menu,1);
 	group_hide(gui->base_menu,1);
 	group_hide(gui->main_menu,1);
 	group_hide(gui->load_menu,1);
 	group_hide(gui->save_menu,1);
 	group_hide(gui->opt_menu,1);
+
+	/* XXX it's misplaced here but the easy way ... */
+	group_hide(gui->unit_buttons,1);
+	group_hide(gui->split_menu,1);
 	mmview_hide(gui->minimap,1);
 }
 void gui_panel_show()
 {
 	frame_hide(gui->panel,0);
-	group_hide(gui->unit_buttons,0);
-	group_hide(gui->split_menu,1);
 	group_hide(gui->base_menu,0);
 	group_hide(gui->main_menu,0);
 	group_hide(gui->load_menu,1);
 	group_hide(gui->save_menu,1);
 	group_hide(gui->opt_menu,1);
-	mmview_hide(gui->minimap,0);
 }
 void gui_resize_panel()
 {
