@@ -64,7 +64,8 @@ extern Setup setup;
 
 /* command line stuff */
 static int suppress_title;
-static List *player_control;
+int ctloptnum = 0, ctloptmax=2;
+int ctlopts[2];
 
 enum Options { OPT_HELP = 256, OPT_CONTROL, OPT_SPEED, OPT_VERSION,
                OPT_CAMPAIGN_START, OPT_AI_DEBUG };
@@ -84,6 +85,7 @@ static struct option long_options[] = {
     { 0, 0, 0, 0 }
 };
 
+#if 0
 static void show_title()
 {
     int dummy;
@@ -117,6 +119,7 @@ static void show_title()
     free_surf(&back);
     free_font(&font);
 }
+#endif
 
 /* aborts with the given error message and exit code 1 */
 static void abortf(const char *fmt, ...) {
@@ -159,7 +162,7 @@ static void syntax(int argc, char *argv[])
 static void print_version()
 {
     /* display some credits */
-    printf( tr("LGeneral %s\nCopyright 2001-2017 Michael Speck\nPublished under GNU GPL\n---\n"), VERSION );
+    printf( tr("LGeneral %s\nCopyright 2001-%d Michael Speck\nPublished under GNU GPL\n---\n"), VERSION, 2021 );
     printf( tr("Looking up data in: %s\n"), get_gamedir() );
 #ifndef WITH_SOUND
     printf( tr("Compiled without sound and music\n") );
@@ -169,6 +172,12 @@ static void print_version()
 static void add_control(const char *ctlspec)
 {
     int ctl = PLAYER_CTRL_NOBODY;
+
+    if (ctloptnum == ctloptmax) {
+	    fprintf(stderr,"Too many command line control options (max: %d)\n",ctloptmax);
+	    return;
+    }
+
     assert(ctlspec);
     switch (ctlspec[0]) {
         case 'C':
@@ -185,10 +194,7 @@ static void add_control(const char *ctlspec)
     if (ctl != PLAYER_CTRL_CPU && ctl != PLAYER_CTRL_HUMAN)
         abortf(tr("Invalid player control: %s\n"), ctlspec);
 
-    if (!player_control)
-        player_control = list_create(LIST_NO_AUTO_DELETE, LIST_NO_CALLBACK);
-
-    list_add(player_control, (void *)ctl);
+    ctlopts[ctloptnum++] = ctl;
 }
 
 static void eval_cmdline(int argc, char **argv)
@@ -232,11 +238,11 @@ static void eval_cmdline(int argc, char **argv)
         suppress_title = 1;
         if (load == LOAD_SCEN || load == LOAD_CAMP) {
             /* apply control */
-            if (player_control) {
-                int ctl, i;
-                list_reset(player_control);
-                for (i = 0; i < setup.player_count && (ctl = (int)list_next(player_control)); i++)
-                    setup.ctrl[i] = ctl;
+            if (ctloptnum > 0) {
+                int i;
+                for (i = 0; i < setup.player_count && i < ctloptnum; i++) {
+                    setup.ctrl[i] = ctlopts[i];
+                }
             }
         }
     }
@@ -260,7 +266,7 @@ int main(int argc, char *argv[])
     
     /* init sdl */
     init_sdl( SDL_INIT_VIDEO | SDL_INIT_TIMER | SDL_INIT_AUDIO );
-    set_video_mode( 640, 480, 0 );
+    set_video_mode( 800, 600, config.fullscreen );
     sprintf( window_name, tr("LGeneral %s"), VERSION );
     SDL_WM_SetCaption( window_name, 0 );
     event_enable_filter();
@@ -294,6 +300,5 @@ int main(int argc, char *argv[])
 
     event_disable_filter();
 
-    if (player_control) list_delete(player_control);
     return 0;
 }
