@@ -460,6 +460,12 @@ static int parser_read_file_full( ParserState *st, PData *top )
 }
 static int parser_read_file_compact( ParserState *st, PData *section )
 {
+	char entryToken1 = 0xbb;
+	char itemToken1 = 0xb0;
+	char entryToken2 = '=';
+	char itemToken2 = '&';
+	int useNewTokens = 0;
+
     /* section is the parent pdata that needs some 
        entries */
     PData *pd = 0;
@@ -479,15 +485,20 @@ static int parser_read_file_compact( ParserState *st, PData *section )
                 break;
             default:
                 /* check name */
-                if ( ( cur = strchr( line, '' ) ) == 0 ) {
-                    sprintf( parser_sub_error, tr("parse error: use '%c' for assignment or '<' for section"), '' );
-                    return 0;
+                if ( ( cur = strchr( line, entryToken1 ) ) == 0 ) {
+                	if ( ( cur = strchr( line, entryToken2 ) ) == 0 ) {
+                		sprintf( parser_sub_error,
+                				tr("parse error: use '%c' or '%c' for assignment or '<' for section"),
+                				entryToken1, entryToken2 );
+                		return 0;
+                	} else
+                		useNewTokens = 1;
                 }
                 cur[0] = 0; cur++;
                 /* read values as subsection */
                 pd = parser_create_pdata(strdup( line ),
-                                         parser_explode_string( cur, '' ),
-                                         st->lineno, st->ctd);
+                               parser_explode_string( cur, useNewTokens?itemToken2:itemToken1 ),
+                               st->lineno, st->ctd);
                 /* add to section */
                 list_add( section->entries, pd );
                 break;
