@@ -708,9 +708,9 @@ static void save_map_tile_flag( FILE *file, Map_Tile *tile )
     else
         save_string( file, "none" );
 	
-	/* deploy level and damage */
-	save_int(file, tile->deploy_center);
-	save_int(file, tile->damaged);
+    /* deploy level and damage */
+    save_int(file, tile->deploy_center);
+    save_int(file, tile->damaged);
 }
 static void load_map_tile_flag( FILE *file, Nation **nation, Player **player,
 					int *deploy_center, int *damaged)
@@ -896,7 +896,7 @@ Save/load game to/from file.
 int slot_save( int id, char *name )
 {
     FILE *file = 0;
-    char path[512];
+    char path[1024];
     int i, j;
     /* NOTE: If you change the savegame-layout, don't forget
        to increase the version and add proper discrimination
@@ -931,7 +931,7 @@ int slot_save( int id, char *name )
     /* if we ever hit this, we have *big* problems */
     COMPILE_TIME_ASSERT(StoreHighestSupportedVersion <= StoreVersionLimit);
     /* get file name */
-    sprintf( path, "%s/lg_save_%i", config.dir_name, id );
+    snprintf( path, 1024, "%s/lg_save_%i", config.dir_name, id );
     /* open file */
     if ( ( file = fopen( path, "wb" ) ) == 0 ) {
         fprintf( stderr, tr("%s: not found\n"), path );
@@ -994,7 +994,7 @@ int slot_save( int id, char *name )
 int slot_load( int id )
 {
     FILE *file = 0;
-    char path[512];
+    char path[1024];
     int camp_saved;
     int i, j;
     char *scen_file_name = 0;
@@ -1003,7 +1003,7 @@ int slot_load( int id )
 	
     store_version = StoreVersionLegacy;
     /* get file name */
-    sprintf( path, "%s/lg_save_%i", config.dir_name, id );
+    snprintf( path, 1024, "%s/lg_save_%i", config.dir_name, id );
     /* open file */
     if ( ( file = fopen( path, "rb" ) ) == 0 ) {
         fprintf( stderr, tr("%s: not found\n"), path );
