@@ -47,7 +47,7 @@ extern Mask_Tile **mask;
 extern Map_Tile **map;
 extern int air_mode;
 extern Player *cur_player;
-extern int gui_panel_w;
+extern GUI *gui;
 
 /*
 ====================================================================
@@ -330,7 +330,7 @@ void strat_map_create()
     dots = list_create( LIST_AUTO_DELETE, LIST_NO_CALLBACK );
 
     /* create our smaller brother */
-    minimap_create(gui_panel_w - 10, gui_panel_w - 1);
+    minimap_create(gui->minimap->w -4, gui->minimap->h -4);
 }
 
 /*
