@@ -885,7 +885,8 @@ void unit_get_damage( Unit *aggressor, Unit *unit, Unit *target,
         if (max_roll>12)
             kill_chance = 0.05*(max_roll-MAXIMUM(13,min_roll)+1);
     }
-    if (suppr_chance<0) suppr_chance=0; if (kill_chance<0) kill_chance=0;
+    if (suppr_chance<0) suppr_chance=0;
+    if (kill_chance<0) kill_chance=0;
     if ( real ) {
 #ifdef DEBUG_ATTACK
         printf( "Roll: D20 + %i (Kill: %i%%, Suppr: %i%%)\n", 
