@@ -671,7 +671,7 @@ int lbox_handle_button( LBox *lbox, int button_id, int cx, int cy, Button **butt
         lbox->cell_offset -= lbox->step;
         if ( lbox->cell_offset < 0 )
             lbox->cell_offset = 0;
-            lbox_apply( lbox );
+        lbox_apply( lbox );
         return 1;
     }
     else
@@ -879,7 +879,7 @@ handle_click
 */
 int fdlg_handle_button( FDlg *fdlg, int button_id, int cx, int cy, Button **button )
 {
-    char path[512];
+    char path[2048];
     void *item = 0;
     char *fname;
     if ( !fdlg->group->frame->img->bkgnd->hide ) {
@@ -906,7 +906,7 @@ int fdlg_handle_button( FDlg *fdlg, int button_id, int cx, int cy, Button **butt
                     if ( fdlg->subdir[0] == 0 )
                         strcpy( path, fdlg->root );
                     else
-                        sprintf( path, "%s/%s", fdlg->root, fdlg->subdir );
+                        snprintf( path, 2048, "%s/%s", fdlg->root, fdlg->subdir );
                     lbox_set_items( fdlg->lbox, dir_get_entries( path, fdlg->root, 0 ) );
                     (fdlg->file_cb)( 0, fdlg->info_buffer );
                 }
@@ -915,7 +915,7 @@ int fdlg_handle_button( FDlg *fdlg, int button_id, int cx, int cy, Button **butt
                     if ( fdlg->subdir[0] == 0 )
                         strcpy( path, fname );
                     else
-                        sprintf( path, "%s/%s", fdlg->subdir, fname );
+                        snprintf( path, 2048, "%s/%s", fdlg->subdir, fname );
                     (fdlg->file_cb)( path, fdlg->info_buffer );
                 }
                 DEST( fdlg->group->frame->contents, fdlg->info_x, fdlg->info_y, fdlg->info_buffer->w, fdlg->info_buffer->h );
@@ -1331,6 +1331,12 @@ void mmview_move(MMView *mmv, int x, int y)
 	frame_move(mmv->minimap_frame,x,y);
 }
 
+void mmview_hide(MMView *mmv, int hide)
+{
+	frame_hide(mmv->minimap_frame,hide);
+	mmv->hidden = hide;
+}
+
 void mmview_render(MMView *mmv, int full)
 {
 	Frame *mmf = mmv->minimap_frame;
