@@ -556,6 +556,7 @@ typedef struct {
 	int w,h; /* of minimap frame, actual size is extern mm_width/height */
 	int vsx, vsy; /* start position in frame */
 	int vx, vy, vw, vh; /* of viewport in minimap */
+	int hidden; /* whether not shown currently */
 } MMView;
 
 MMView *mmview_create(int w, int h);
@@ -564,8 +565,9 @@ void mmview_resize_viewport(MMView *mmv);
 void mmview_adjust_viewport(MMView *mmv);
 void mmview_move(MMView *mmv, int x, int y);
 #define mmview_get_bkgnd(__MMV) frame_get_bkgnd((__MMV)->minimap_frame)
+#define mmview_draw_bkgnd(__MMV) frame_draw_bkgnd((__MMV)->minimap_frame)
 #define mmview_draw(__MMV) frame_draw((__MMV)->minimap_frame)
-#define mmview_hide(__MMV,__ON) frame_hide((__MMV)->minimap_frame,__ON)
+void mmview_hide(MMView *mmv, int hide);
 void mmview_render(MMView *mmv, int full);
 int mmview_handle_click( MMView *mmv, int button_id, int x, int y, int *newx, int *newy );
 int mmview_handle_motion( MMView *mmv, int x, int y, int *newx, int *newy );
